@@ -17,27 +17,36 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   SVN:$Id: grid.h 121 2008-01-10 00:17:40Z olivier $
+ *   SVN:$Id: grid.h 551 2009-04-30 10:38:56Z olivier $
  */
 
 #include <gtk/gtk.h>
 
 typedef struct grid_t grid_t;
-typedef void(* grid_cell_changed_callback_t) (void *data, int col, int row, int value);
+
+typedef struct {
+    int col;
+    int row;
+    int value;
+} grid_cell_state_t;
 
 grid_t *    grid_new                          ();
+void        grid_destroy                      (grid_t *grid);
 void        grid_resize                       (grid_t *grid, int col_num, int row_num);
 GtkWidget * grid_get_widget                   (grid_t *grid);
 void        grid_set_value                    (grid_t *grid, int col, int row, int value);
 void        grid_set_mask                     (grid_t *grid, int col, int row, int mask);
-void        grid_set_value_changed_callback   (grid_t *grid, grid_cell_changed_callback_t callback, void *data);
-void        grid_set_mask_changed_callback    (grid_t *grid, grid_cell_changed_callback_t callback, void *data);
 void        grid_highlight_cell               (grid_t *grid, int col, int row, float level);
 void        grid_set_cell_size                (grid_t *grid, int min_width, int max_width, 
                                                int min_height, int max_height);
-void        grid_set_spacing                  (grid_t *grid, int col_spacing, int row_spacing);
+void        grid_set_spacing                  (grid_t *grid, int min_col_spacing, int row_spacing);
 void        grid_set_column_group_size        (grid_t *grid, int column_num);
 void        grid_set_header_height            (grid_t *grid, int height);
+void        grid_set_header_height_no_redraw  (grid_t *grid, int height);
+void        grid_set_vpadding                 (grid_t *grid, int padding);
 void        grid_set_header_label_ypos        (grid_t *grid, int y);
+void        grid_set_scroll_adjustments       (grid_t* grid, GtkAdjustment *hadj, GtkAdjustment *vadj);
+int         grid_get_minimum_width            (grid_t *grid);
+int         grid_get_minimum_height           (grid_t *grid);
 
 
