@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   SVN:$Id: sequenceeditor.c 610 2009-06-26 12:49:33Z olivier $
+ *   SVN:$Id: sequenceeditor.c 643 2009-11-23 19:38:59Z olivier $
  */
 
 #include <stdlib.h>
@@ -118,6 +118,20 @@ gui_sequence_editor_remove_track (GtkWidget * menu_item, gui_sequence_editor_con
   sequence_remove_track (self->sequence, ctl->track);
 }
 
+static void
+gui_sequence_editor_move_track_up (GtkWidget * menu_item, gui_sequence_editor_control_t * ctl)
+{
+  gui_sequence_editor_t *self = ctl->editor; 
+  sequence_swap_tracks(self->sequence, ctl->track, ctl->track - 1);
+}
+
+static void
+gui_sequence_editor_move_track_down (GtkWidget * menu_item, gui_sequence_editor_control_t * ctl)
+{
+  gui_sequence_editor_t *self = ctl->editor;  
+  sequence_swap_tracks(self->sequence, ctl->track, ctl->track + 1);
+}
+
 static void
 gui_sequence_editor_set_active_track (gui_sequence_editor_t *self, int track, int redraw)
 {
@@ -181,29 +195,37 @@ gui_sequence_editor_make_menu (gui_sequence_editor_t *self, int track)
   GtkWidget *menu;
   GtkWidget *item;
   gui_sequence_editor_control_t *ctl;
-  
+  int tracks_num = sequence_get_tracks_num (self->sequence);
+
   ctl = self->controls + track;
 
   menu = gtk_menu_new ();
 
   gui_misc_add_menu_item (menu, "#item", "Load sample...", G_CALLBACK (gui_sequence_editor_load_sample), 
-                     (gpointer) ctl, NULL);
+                          (gpointer) ctl, NULL);
 
-  /* FIXME
-  GtkWidget *submenu = gui_file_build_recent_samples_menu (self, track);
-  item = gui_add_menu_item (menu, "#item", "Recent", NULL, NULL, NULL);
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
+  gui_misc_add_menu_item (menu, "#item", "Rename track...", G_CALLBACK (gui_sequence_editor_rename_track), 
+                          (gpointer) ctl, NULL);
 
-  gui_add_menu_item (menu, "#separator", NULL, NULL, NULL, NULL);
-  */
+  gui_misc_add_menu_item (menu, "#separator", NULL, NULL, NULL, NULL);
 
-  item = gui_misc_add_menu_item (menu, "#item", "Rename...", G_CALLBACK
-                            (gui_sequence_editor_rename_track), (gpointer) ctl, NULL);
+  item = gui_misc_add_menu_item (menu, "#item", "Move up", G_CALLBACK (gui_sequence_editor_move_track_up), 
+                                 (gpointer) ctl, NULL);
+  if (track == 0)
+      gtk_widget_set_sensitive (item, FALSE);
+
+  item = gui_misc_add_menu_item (menu, "#item", "Move down", G_CALLBACK (gui_sequence_editor_move_track_down), 
+                                 (gpointer) ctl, NULL);
+
+  if (track == tracks_num - 1)
+      gtk_widget_set_sensitive (item, FALSE);
+
+  gui_misc_add_menu_item (menu, "#separator", NULL, NULL, NULL, NULL);
 
   item = gui_misc_add_menu_item (menu, "#stock", GTK_STOCK_REMOVE, G_CALLBACK
                             (gui_sequence_editor_remove_track), (gpointer) ctl, NULL);
 
-  if (sequence_get_tracks_num (self->sequence) == 1)
+  if (tracks_num == 1)
     gtk_widget_set_sensitive (item, FALSE);
 
   return menu;
@@ -723,6 +745,7 @@ gui_sequence_editor_new (sequence_t *sequence)
 
   event_subscribe (self->sequence, "beat-changed", self, gui_sequence_editor_on_beat_changed);
   event_subscribe (self->sequence, "resized", self, gui_sequence_editor_on_resize);
+  event_subscribe (self->sequence, "reordered", self, gui_sequence_editor_on_resize);
   event_subscribe (self->sequence, "track-mute-changed", self, gui_sequence_editor_on_mute_changed);
   event_subscribe (self->sequence, "track-solo-changed", self, gui_sequence_editor_on_solo_changed);
   event_subscribe (self->sequence, "track-volume-changed", self, gui_sequence_editor_on_volume_changed);
