@@ -17,22 +17,24 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   SVN:$Id: jab.h 121 2008-01-10 00:17:40Z olivier $
+ *   SVN:$Id: jab.h 282 2008-09-03 12:26:13Z olivier $
  */
 
 #ifndef JACKBEAT_JAB_H
 #define JACKBEAT_JAB_H
 
 #include "types.h"
+#include "core/event.h"
+#include "stream/stream.h"
 
 #define JAB_WRITE 1
 #define JAB_READ 2
 
 typedef struct jab_t jab_t;
 
-jab_t *       jab_open (char *path, int mode, progress_callback_t progress_callback, void *progress_data);
+jab_t *       jab_open (char *path, int mode, progress_callback_t progress_callback, void *progress_data, int *error);
 void          jab_add_sequence (jab_t *jab, sequence_t *sequence);
-sequence_t *  jab_retrieve_sequence (jab_t *jab, char *sequence_name, int *error);
+sequence_t *  jab_retrieve_sequence (jab_t *jab, stream_t *stream, char *sequence_name, int *error);
 int           jab_close (jab_t *jab);
 
 #endif
