@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   SVN:$Id: rc.h 124 2008-01-10 19:10:45Z olivier $
+ *   SVN:$Id: rc.h 291 2008-09-08 17:25:49Z olivier $
  */
 
 #ifndef JACKBEAT_RC_H
@@ -37,9 +37,13 @@ typedef struct rc_t
   int       transport_aware;
   int       transport_query;
   int       auto_connect;
+  int       osc_input_port;
+  char      client_name[512];
+  char      audio_output[512];
+  int       audio_sample_rate;
+  int       jack_auto_start;
 } rc_t;
 
-
 void rc_write (rc_t * rc);
 void rc_read (rc_t *rc);
 void rc_add_sample (rc_t *rc, char *filename);
