@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   SVN:$Id: sequence.h 610 2009-06-26 12:49:33Z olivier $
+ *   SVN:$Id: sequence.h 643 2009-11-23 19:38:59Z olivier $
  */
 
 #ifndef JACKBEAT_SEQUENCE_H
@@ -102,11 +102,12 @@ void    sequence_set_bpm (sequence_t *sequence, float bpm);
 void    sequence_set_looping (sequence_t *sequence);
 void    sequence_unset_looping (sequence_t *sequence);
 int     sequence_is_looping(sequence_t *sequence);
-
+void    sequence_swap_tracks(sequence_t *sequence, int track1, int track2);
 
 /* Track informations */
 char *  sequence_get_track_name (sequence_t *sequence, int track);
 int     sequence_set_track_name (sequence_t *sequence, int track, char *name);
+int     sequence_force_track_name(sequence_t *sequence, int track, char *name);
 int     sequence_track_name_exists (sequence_t *sequence, char *name);
 sequence_track_type_t sequence_get_track_type (sequence_t *sequence, int track);
 
